#!/usr/bin/php
<?php
/*
 check_radius_auth.php
 Icinga / Nagios check Plugin to check Radius authentication with MSCHAP and other authentication protocols, something that other Radius check scripts fail to do. Needs freeradius-utils to be installed.
 (C) GEOTEK Datentechnik Berlin, Martin Kasztantowicz
 https://geotek.de/ - info@geotek.de

 V.1.0
*/ 


$msg = '';
$err = '';
$return_code = 3;
$return_status = array(0 => 'OK', 1 => 'WARNING', 2 => 'CRITICAL', 3 => 'UNKNOWN');
// We must use double quotes to make Newline working on the commandline!
$usage = "Usage: check_radius_auth.php -H <host> -s <secret> -m pap|chap|mschap|eap-md5 -u <username> -p <password> -e <expect-string>\n";
// $argstr = var_export($argv, true);

// Parse ommand line
$options = getopt('H:s:m:u:p:e:');

$host = (isset($options['H'])) ? $options['H'] : '';
if ($host == '') {
  // We must use double quotes to make Newline working on the commandline!
  $err .= "-H Host parameter missing\n";
}

$secret = (isset($options['s'])) ? $options['s'] : '';
if ($secret == '') {
  // We must use double quotes to make Newline working on the commandline!
  $err .= "-s Secret parameter missing\n";
}

$auth_method = (isset($options['m'])) ? $options['m'] : '';
if ($auth_method == '') {
  // We must use double quotes to make Newline working on the commandline!
  $err .= "-m Authentication method pap|chap|mschap|eap-md5 missing\n";
}

$username = (isset($options['u'])) ? $options['u'] : '';
if ($username == '') {
  $err .= "-u Username missing\n";
}

$password = (isset($options['p'])) ? $options['p'] : '';
if ($password == '') {
  $err .= "-p Password missing\n";
}

$expect = (isset($options['e'])) ? $options['e'] : '';
if ($expect == '') {
  // We must use double quotes to make Newline working on the commandline!
  $err .= "-e Expect sring missing\n";
}

if ($err != '') abort("\n".$err.$usage);

$cmd = "radtest -t ".$auth_method." ".$username." ".$password." ".$host." 10 ".$secret;
$return = shell_exec($cmd." 2>/dev/null");

if (empty($return)) {
	echo "Unknown rusult: \n".$return;
	exit(3);		// Unkonwn
}
if (strpos($return, $expect, 0) == false) {
	echo "Critical - Radius Authentication failed\n".$return;
	exit(2);		// Critical
}
//´expect string found
echo "OK - Radius Authentication successful\n";
exit(0);


function abort($msg) {
  global $return_code, $return_status;
    echo $return_status[$return_code].' - '.$msg;
    exit($return_code);
}

?>
